<?php
/**
 * mk language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesMk.php?view=co
 * @author Dimitar Talevski <dimi3.14@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Уреди ја страницата';
$lang['btn_source']            = 'Прикажи ја изворната страница';
$lang['btn_show']              = 'Прикажи страница';
$lang['btn_create']            = 'Креирај ја оваа страница';
$lang['btn_search']            = 'Барај';
$lang['btn_save']              = 'Зачувај';
$lang['btn_preview']           = 'Преглед';
$lang['btn_top']               = 'Назад до врв';
$lang['btn_newer']             = '<< понови';
$lang['btn_older']             = 'постари >>';
$lang['btn_revs']              = 'Стари ревизии';
$lang['btn_recent']            = 'Скорешни промени';
$lang['btn_upload']            = 'Крени';
$lang['btn_cancel']            = 'Откажи';
$lang['btn_index']             = 'Индекс';
$lang['btn_secedit']           = 'Уреди';
$lang['btn_login']             = 'Најава';
$lang['btn_logout']            = 'Одјава';
$lang['btn_admin']             = 'Админ';
$lang['btn_update']            = 'Ажурирај';
$lang['btn_delete']            = 'Избриши';
$lang['btn_back']              = 'Назад';
$lang['btn_backlink']          = 'Повратни врски';
$lang['btn_backtomedia']       = 'Назад до изборот за медиа-датотека';
$lang['btn_subscribe']         = 'Менаџирај претплати';
$lang['btn_profile']           = 'Ажурирај профил';
$lang['btn_reset']             = 'Ресет';
$lang['btn_draft']             = 'Уреди скица';
$lang['btn_recover']           = 'Поврати скица';
$lang['btn_draftdel']          = 'Избриши скица';
$lang['btn_revert']            = 'Обнови';
$lang['btn_register']          = 'Регистрирај се';
$lang['loggedinas']            = 'Најавен/а како';
$lang['user']                  = 'Корисничко име';
$lang['pass']                  = 'Лозинка';
$lang['newpass']               = 'Нова лозинка';
$lang['oldpass']               = 'Потврдете ја сегашната лозинка';
$lang['passchk']               = 'уште еднаш';
$lang['remember']              = 'Запомни ме';
$lang['fullname']              = 'Вистинско име';
$lang['email']                 = 'Е-пошта';
$lang['profile']               = 'Кориснички профил';
$lang['badlogin']              = 'Жалам, корисничкото име или лозинката се погрешни.';
$lang['minoredit']             = 'Мали измени';
$lang['draftdate']             = 'Скицата е само-снимена на';
$lang['nosecedit']             = 'Во меѓувреме страницата беше променета, информацискиот дел е со истечен период затоа се вчита целата страница.';
$lang['regmissing']            = 'Жалам, мора да ги пополнеш сите полиња.';
$lang['reguexists']            = 'Жалам, корисник со ова корисничко име веќе постои.';
$lang['regsuccess']            = 'Корисникот е креиран и лозинката е испратена по е-пошта.';
$lang['regsuccess2']           = 'Корисникот е креиран.';
$lang['regmailfail']           = 'Изгледа дека се појави грешка при испраќањето на е-пошта со лозинката. Ве молам контактирајте го администраторот!';
$lang['regbadmail']            = 'Дадената адреса за е-пошта изгледа невалидна - ако мислите дека ова е грешка, контактирајте го администраторот';
$lang['regbadpass']            = 'Двете наведени лозинки не се исти, ве молам пробајте повторно.';
$lang['regpwmail']             = 'Вашата DokuWiki лозинка';
$lang['reghere']               = 'Се уште немаш сметка? Направи веќе една';
$lang['profna']                = 'Ова вики не поддржува измена на профилот';
$lang['profnochange']          = 'Нема промени, ништо за правење.';
$lang['profnoempty']           = 'Празно име или адреса за е-пошта не е дозволено.';
$lang['profchanged']           = 'Корисничкиот профил е успешно ажуриран.';
$lang['pwdforget']             = 'Ја заборавивте лозинката? Добијте нова';
$lang['resendna']              = 'Ова вики не поддржува повторно испраќање на лозинка.';
$lang['resendpwdmissing']      = 'Жалам, морате да ги пополните сите полиња.';
$lang['resendpwdnouser']       = 'Жалам, таков корисник не постои во нашата база со податоци.';
$lang['resendpwdbadauth']      = 'Жалам, овај код за валидација не е валиден. Проверете повторно дали ја искористивте целосната врска за потврда.';
$lang['resendpwdconfirm']      = 'Врска за потврда е испратена по е-пошта.';
$lang['resendpwdsuccess']      = 'Вашата нова лозинка е испратена по е-пошта.';
$lang['license']               = 'Освен каде што е наведено поинаку, содржината на ова вики е лиценцирано по следнава лиценца:';
$lang['licenseok']             = 'Забелешка: со уредување на оваа страница се согласувате да ја лиценцирате вашата содржина под следнава лиценца:';
$lang['searchmedia']           = 'Барај име на датотека:';
$lang['searchmedia_in']        = 'Барај во %s';
$lang['txt_upload']            = 'Избери датотека за качување';
$lang['txt_filename']          = 'Качи како (неморално)';
$lang['txt_overwrt']           = 'Пребриши ја веќе постоечката датотека';
$lang['lockedby']              = 'Моментално заклучена од';
$lang['lockexpire']            = 'Клучот истекува на';
$lang['js']['willexpire']            = 'Вашиот клуч за уредување на оваа страница ќе истече за една минута.\nЗа да избегнете конфликти и да го ресетирате бројачот за време, искористете го копчето за преглед.';
$lang['js']['notsavedyet']     = 'Незачуваните промени ќе бидат изгубени.\nСакате да продолжите?';
$lang['rssfailed']             = 'Се појави грешка при повлекувањето на овој канал:';
$lang['nothingfound']          = 'Ништо не е пронајдено.';
$lang['mediaselect']           = 'Медиа датотеки';
$lang['fileupload']            = 'Качување на медиа датотеки';
$lang['uploadsucc']            = 'Качувањето е успешно';
$lang['uploadfail']            = 'Качувањето не е успешно. Можеби има погрешни пермисии?';
$lang['uploadwrong']           = 'Качувањето е одбиено. Наставката на датотеката е забранета!';
$lang['uploadexist']           = 'Датотеката веќе постои. Ништо не е направено.';
$lang['uploadbadcontent']      = 'Качената содржина не се совпаѓа со наставката %s на датотеката.';
$lang['uploadspam']            = 'Качувањето беше блокирано од црната листа за спам.';
$lang['uploadxss']             = 'Качувањето беше блокирано за можна злонамерна содржина.';
$lang['uploadsize']            = 'Датотеката за качување е премногу голема. (макс. %s)';
$lang['deletesucc']            = 'Датотеката „%s“ е избришана.';
$lang['deletefail']            = '„%s“ не може да се избрише - проверете пермисии.';
$lang['mediainuse']            = 'Датотеката „%s“ не е избришана - се уште е во употреба.';
$lang['mediafiles']            = 'Достапни датотеки во';
$lang['js']['searchmedia']     = 'Барај датотеки';
$lang['js']['keepopen']        = 'Задржи го прозорецот отворен на означеното место';
$lang['js']['hidedetails']     = 'Скриј детали';
$lang['js']['nosmblinks']      = 'Поврзувањето со Windows Shares работи само со Microsoft Internet Explorer. Сепак можете да ја копирате и вметнете врската.';
$lang['js']['linkwiz']         = 'Волшебник за врски';
$lang['js']['linkto']          = 'Врска до:';
$lang['js']['del_confirm']     = 'Дали навистина да ги избришам избраните датотеки?';
$lang['mediausage']            = 'Користете ја следнава синтакса за референцирање кон оваа датотека:';
$lang['mediaview']             = 'Види ја оригиналната датотека';
$lang['mediaroot']             = 'root';
$lang['mediaextchange']        = 'Наставката на датотеката е сменета од .%s во .%s!';
$lang['reference']             = 'Референци за';
$lang['ref_inuse']             = 'Датотеката не може да биде избришана бидејќи се уште се користи од следниве страници:';
$lang['ref_hidden']            = 'Некои референци се на страници на кои немате пермисии за читање';
$lang['hits']                  = 'Прегледи';
$lang['quickhits']             = 'Совпаѓачки имиња на страници';
$lang['toc']                   = 'Содржина';
$lang['current']               = 'сегашно';
$lang['yours']                 = 'Вашата верзија';
$lang['diff']                  = 'Прикажи разлики со сегашната верзија';
$lang['diff2']                 = 'Прикажи разлики помеѓу избраните ревизии';
$lang['line']                  = 'Линија';
$lang['breadcrumb']            = 'Следи';
$lang['youarehere']            = 'Вие сте тука';
$lang['lastmod']               = 'Последно изменета';
$lang['by']                    = 'од';
$lang['deleted']               = 'отстранета';
$lang['created']               = 'креирана';
$lang['restored']              = 'обновена е стара ревизија (%s)';
$lang['external_edit']         = 'надворешно уредување';
$lang['summary']               = 'Уреди го изводот';
$lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash приклучокот</a> е потребен за да се прикаже оваа содржина.';
$lang['download']              = 'Симни Snippe';
$lang['mail_newpage']          = 'додадена е страницата:';
$lang['mail_changed']          = 'променета е страницата:';
$lang['mail_new_user']         = 'нов корисник:';
$lang['mail_upload']           = 'качена е датотеката:';
$lang['qb_bold']               = 'Задебелен текст';
$lang['qb_italic']             = 'Накосен текст';
$lang['qb_underl']             = 'Подвлечен текст';
$lang['qb_code']               = 'Текст за код';
$lang['qb_strike']             = 'Прецртан текст';
$lang['qb_h1']                 = 'Заглавие од 1-во ниво';
$lang['qb_h2']                 = 'Заглавие од 2-ро ниво';
$lang['qb_h3']                 = 'Заглавие од 3-то ниво';
$lang['qb_h4']                 = 'Заглавие од 4-то ниво';
$lang['qb_h5']                 = 'Заглавие од 5-то ниво';
$lang['qb_h']                  = 'Заглавие';
$lang['qb_hs']                 = 'Избери заглавие';
$lang['qb_hplus']              = 'Зголеми заглавие';
$lang['qb_hminus']             = 'Намали заглавие';
$lang['qb_hequal']             = 'Заглавие од исто ниво';
$lang['qb_link']               = 'Внатрешна врска';
$lang['qb_extlink']            = 'Надворешна врска';
$lang['qb_hr']                 = 'Хоризонтален линијар';
$lang['qb_media']              = 'Додај слики и други датотеки';
$lang['qb_sig']                = 'Внеси потпис';
$lang['qb_smileys']            = 'Смајлиња';
$lang['qb_chars']              = 'Специјални знаци';
$lang['admin_register']        = 'Додај нов корисник';
$lang['metaedit']              = 'Уреди мета-податоци';
$lang['metasaveerr']           = 'Запишување на мета-податоците не успеа';
$lang['metasaveok']            = 'Мета-податоците се зачувани';
$lang['btn_img_backto']            = 'Назад до %s';
$lang['img_title']             = 'Насловна линија';
$lang['img_caption']           = 'Наслов';
$lang['img_date']              = 'Датум';
$lang['img_fname']             = 'Име на датотека';
$lang['img_fsize']             = 'Големина';
$lang['img_artist']            = 'Фотограф';
$lang['img_copyr']             = 'Авторско право';
$lang['img_format']            = 'Формат';
$lang['img_camera']            = 'Камера';
$lang['img_keywords']          = 'Клучни зборови';
$lang['subscr_subscribe_success'] = 'Додаден/а е %s во претплатничката листа за %s';
$lang['subscr_subscribe_error'] = 'Грешка при додавањето на %s во претплатничката листа за %s';
$lang['subscr_subscribe_noaddress'] = 'Нема адреса за е-пошта поврзана со Вашата најава, не може да бидете додадени на претплатничката листа';
$lang['subscr_unsubscribe_success'] = 'Отстранет/а е %s од претплатничката листа за %s';
$lang['subscr_unsubscribe_error'] = 'Грешка при отстранувањето на %s од претплатничката листа за %s';
$lang['subscr_already_subscribed'] = '%s е веќе претплатен/а на %s';
$lang['subscr_not_subscribed'] = '%s е не претплатен/а на %s';
$lang['subscr_m_not_subscribed'] = 'Моментално не сте пријавени на сегашната страница или ';
$lang['subscr_m_new_header']   = 'Додај претплата';
$lang['subscr_m_current_header'] = 'Моментални претплати';
$lang['subscr_m_unsubscribe']  = 'Отплатување';
$lang['subscr_m_subscribe']    = 'Претплата';
$lang['subscr_m_receive']      = 'Прими';
$lang['subscr_style_every']    = 'е-пошта за секоја промена';
$lang['authtempfail']          = 'Автентикација на корисник е привремено недостапна. Ако оваа ситуација истрајува, ве молам известете го вики администратор.';
$lang['i_chooselang']          = 'Избере јазик';
$lang['i_installer']           = 'Инсталер за DokuWiki';
$lang['i_wikiname']            = 'вики име';
$lang['i_enableacl']           = 'Овозможи ACL (препорачано)';
$lang['i_superuser']           = 'Супер корисник';
$lang['i_problems']            = 'Инсталерот пронајде неколку проблеми кои се прикажани подолу. Не можете да продолжите понатаму се додека не ги поправите.';
$lang['i_modified']            = 'За безбедносни причини оваа скрипта ќе работи само со нова и неизменета инсталација од DokuWiki. Или извадете ги повторно датотеките од симнатиот пакет или консултирајте се со комплетните <a href="http://dokuwiki.org/install">Dokuwiki инструкции за инсталација</a>';
$lang['i_funcna']              = 'PHP функцијата <code>%s</code> не е достапна. Можеби вашиот хостинг провајдер ја оневозможил со причина?';
$lang['i_phpver']              = 'Вашата верзија на PHP <code>%s</code> е пониска од потребната <code>%s</code>. Треба да ја надградите вашата PHP инсталација.';
$lang['i_permfail']            = '<code>%s</code> не е запишлива од DokuWiki. Треба да ги поправите подесувањата за пермисии на овој директориум!';
$lang['i_confexists']          = '<code>%s</code> веќе постои';
$lang['i_writeerr']            = 'Не може да се креира <code>%s</code>. Треба да ги проверите пермисиите на директориумот/датотеката и рачно да ја креирате датотеката.';
$lang['i_badhash']             = 'непозната или изменете dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - нелегална или празна вредност';
$lang['i_success']             = 'Конфигурацијата успешно заврши. Сега можете да ја избришете датотеката install.php. Продолжете до <a href="doku.php?id=wiki:welcome">вашето ново DokuWiki</a>.';
$lang['i_failure']             = 'Се појавија некои грешки при запишувањето на конфигурациските датотеки. Можеби треба да ги поравите рачно пред да можете да го користите <a href="doku.php?id=wiki:welcome">вашето ново DokuWiki</a>.';
$lang['i_policy']              = 'Почетна ACL политика';
$lang['i_pol0']                = 'Отвори вики (читај, запиши, качи за сите)';
$lang['i_pol1']                = 'Јавно вики (читај за сите, запиши и качи за регистрирани корисници)';
$lang['i_pol2']                = 'Затворено вики (читај, запиши, качи само за регистрирани корисници)';
$lang['i_retry']               = 'Пробај повторно';
$lang['years']                 = 'пред %d години';
$lang['months']                = 'пред %d месеци';
$lang['weeks']                 = 'пред %d недели';
$lang['days']                  = 'пред %d денови';
$lang['hours']                 = 'пред %d часа';
$lang['minutes']               = 'пред %d минути';
$lang['seconds']               = 'пред %d секунди';
